=====================================
numpydoc -- Numpy's Sphinx extensions
=====================================

Numpy's documentation uses several custom extensions to Sphinx.  These
are shipped in this ``numpydoc`` package, in case you want to make use
of them in third-party projects.

The ``numpydoc`` extension provides support for the Numpy docstring format in
Sphinx, and adds the code description directives ``np:function``,
``np-c:function``, etc.  that support the Numpy docstring syntax.

- Development: https://github.com/numpy/numpydoc/
- Documentation: https://numpydoc.readthedocs.io/
- PyPI: https://pypi.python.org/pypi/numpydoc/


Documentation
=============

.. toctree::
    :maxdepth: 2

    install
    release_notes
    format
    example
    validation
